"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const schematics_1 = require("@angular-devkit/schematics");
const testing_1 = require("@angular-devkit/schematics/testing");
const test_1 = require("@schematics/angular/utility/test");
const test_utils_1 = require("../test-utils");
describe('ngx-semantic-version schematic', () => {
    const schematicRunner = new testing_1.SchematicTestRunner('ngx-semantic-version', path_1.resolve(__dirname, '../collection.json'));
    const project = 'foo';
    const defaultOptions = {
        skipInstall: false,
    };
    let appTree;
    beforeEach(() => __awaiter(this, void 0, void 0, function* () {
        appTree = new testing_1.UnitTestTree(new schematics_1.HostTree());
        appTree = yield test_utils_1.setupProject(appTree, schematicRunner, project);
    }));
    describe('when using the default options', () => {
        beforeEach(() => __awaiter(this, void 0, void 0, function* () {
            appTree = yield schematicRunner
                .runSchematicAsync('ng-add', defaultOptions, appTree)
                .toPromise();
        }));
        it(`should add the 'commitlint' configuration file`, () => {
            expect(appTree.files).toContain('/commitlint.config.js');
            const fileContent = test_1.getFileContent(appTree, '/commitlint.config.js');
            expect(fileContent).not.toMatch(/rules: {\s+\'references-empty\': \[2, \'never\'\].\s+\},/g);
            expect(fileContent).not.toMatch(/parserPreset: {\s+parserOpts: \{\s+issuePrefixes: \[\'\PREFIX-\'\],\s+},\s+},/g);
        });
        it(`should add all required dependencies to the 'package.json'`, () => {
            const packageJsonPath = '/package.json';
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { devDependencies } = packageJson;
            expect(appTree.files).toContain(packageJsonPath);
            expect(devDependencies['@commitlint/cli']).toBeDefined();
            expect(devDependencies['@commitlint/config-conventional']).toBeDefined();
            expect(devDependencies.commitizen).toBeDefined();
            expect(devDependencies['cz-conventional-changelog']).toBeDefined();
            expect(devDependencies.husky).toBeDefined();
            expect(devDependencies['standard-version']).toBeDefined();
        });
        it('should add a npm run script', () => {
            const packageJsonPath = '/package.json';
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { scripts } = packageJson;
            expect(appTree.files).toContain(packageJsonPath);
            expect(scripts.release).toEqual('standard-version');
        });
        it(`should add the 'husky' configuration`, () => {
            const packageJsonPath = '/package.json';
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { husky } = packageJson;
            expect(appTree.files).toContain(packageJsonPath);
            expect(husky.hooks['commit-msg']).toEqual('commitlint -E HUSKY_GIT_PARAMS');
        });
        it(`should add the 'commitizen' configuration`, () => {
            const packageJsonPath = '/package.json';
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { config } = packageJson;
            expect(appTree.files).toContain(packageJsonPath);
            expect(config.commitizen.path).toEqual('./node_modules/cz-conventional-changelog');
        });
    });
    describe(`when disabling 'husky'`, () => {
        beforeEach(() => __awaiter(this, void 0, void 0, function* () {
            appTree = yield schematicRunner
                .runSchematicAsync('ng-add', Object.assign({}, defaultOptions, { husky: false }), appTree)
                .toPromise();
        }));
        it(`should not add 'husky' to the project`, () => {
            const packageJsonPath = '/package.json';
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { devDependencies } = packageJson;
            expect(appTree.files).toContain(packageJsonPath);
            expect(devDependencies.husky).not.toBeDefined();
        });
        it(`should skip adding the 'husky' configuration`, () => {
            const packageJsonPath = '/package.json';
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { husky } = packageJson;
            expect(appTree.files).toContain(packageJsonPath);
            expect(husky).not.toBeDefined();
        });
    });
    describe(`when disabling 'commitizen'`, () => {
        beforeEach(() => __awaiter(this, void 0, void 0, function* () {
            appTree = yield schematicRunner
                .runSchematicAsync('ng-add', Object.assign({}, defaultOptions, { commitizen: false }), appTree)
                .toPromise();
        }));
        it(`should not add 'commitizen' to the project`, () => {
            const packageJsonPath = '/package.json';
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { devDependencies } = packageJson;
            expect(appTree.files).toContain(packageJsonPath);
            expect(devDependencies.commitizen).not.toBeDefined();
        });
        it(`should skip adding the 'commitizen' configuration`, () => {
            const packageJsonPath = '/package.json';
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { config } = packageJson;
            expect(appTree.files).toContain(packageJsonPath);
            expect(config).not.toBeDefined();
        });
    });
    describe(`when disabling 'standard-version'`, () => {
        beforeEach(() => __awaiter(this, void 0, void 0, function* () {
            appTree = yield schematicRunner
                .runSchematicAsync('ng-add', Object.assign({}, defaultOptions, { standardVersion: false }), appTree)
                .toPromise();
        }));
        it(`should not add 'standard-version' to the project`, () => {
            const packageJsonPath = '/package.json';
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { devDependencies } = packageJson;
            expect(appTree.files).toContain(packageJsonPath);
            expect(devDependencies['standard-version']).not.toBeDefined();
        });
        it('should skip adding a npm run script', () => {
            const packageJsonPath = '/package.json';
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            const { scripts } = packageJson;
            expect(appTree.files).toContain(packageJsonPath);
            expect(scripts.release).not.toBeDefined();
        });
    });
    describe(`when using an issue prefix`, () => {
        beforeEach(() => __awaiter(this, void 0, void 0, function* () {
            appTree = yield schematicRunner
                .runSchematicAsync('ng-add', Object.assign({}, defaultOptions, { issuePrefix: 'PREFIX-' }), appTree)
                .toPromise();
        }));
        it(`should configure 'issuePrefixes' in '/commitlint.config.js'`, () => {
            expect(appTree.files).toContain('/commitlint.config.js');
            const fileContent = test_1.getFileContent(appTree, '/commitlint.config.js');
            expect(fileContent).toMatch(/rules: {\s+\'references-empty\': \[2, \'never\'\].\s+\},/g);
            expect(fileContent).toMatch(/parserPreset: {\s+parserOpts: \{\s+issuePrefixes: \[\'\PREFIX-\'\],\s+},\s+},/g);
        });
        it(`should add 'standard-version' config`, () => {
            const packageJsonPath = '/package.json';
            const packageJson = JSON.parse(test_1.getFileContent(appTree, packageJsonPath));
            expect(packageJson['standard-version'].issuePrefixes).toContain('PREFIX-');
        });
    });
});
//# sourceMappingURL=index_spec.js.map